# frozen_string_literal: true

require 'cgi'

module Jekyll
  class Embed
    class Content
      URL_RE = /<p[^>]*>[\s\n]*(?<url>https?:\/\/[^<\s\n]+)[\s\n]*<\/p>/m.freeze

      class << self
        # Find URLs on paragraphs.  We do it after rendering because
        # sometimes we use HTML instead of pure Markdown and this way we
        # catch both.
        def embed!(content)
          URL_RE.match(content) do |match|
            embed = Jekyll::Embed.embed CGI.unescapeHTML(match[:url])

            content.sub! URL_RE, embed
          end
        end
      end
    end
  end
end

Jekyll::Hooks.register :posts, :post_convert do |post|
  Jekyll::Embed::Content.embed! post.content
end
